import json
import os

from flask import Flask, render_template, jsonify, send_file, request

from PIL import Image
from io import BytesIO
import base64
import tempfile

app = Flask(__name__)


def load_data_json():
    with open('data.json') as f:
        return json.load(f)


def img_filename(pagenum, dir=None):
    fname = f'image-{pagenum}.jpg'
    if dir:
        fname = os.path.join(dir, fname)
    return fname


@app.route('/')
def index():
    return render_template('index.html')


@app.route('/data')
def get_data():
    return jsonify(load_data_json())


@app.route('/image/<int:pagenum>')
def get_image(pagenum):
    return send_file(img_filename(pagenum, dir='images'))


@app.route('/save', methods=['POST'])
def save_data():
    uploaded = request.get_json().get('images', [])
    data = load_data_json()
    images = {}

    for pagenum in range(1, len(data['pages'])):
        images[pagenum] = Image.open(img_filename(pagenum, dir='images')).convert('RGB')

    for page in uploaded:
        pagenum = page['page']

        background = images[pagenum]
        layer = Image.open(
            BytesIO(
                base64.b64decode(page['data'])
            ),
        )
        background.paste(layer, (0, 0), layer)
        images[pagenum] = background

    images = list(images.values())

    tmp_file = tempfile.NamedTemporaryFile(delete=True)

    images[0].save(
        tmp_file.name, "PDF", resolution=100.0, save_all=True, append_images=images[1:]
    )
    return send_file(
        filename_or_fp=tmp_file.name,
        mimetype='application/pdf',
    )
